use log::info;
use std::env;
use std::env::VarError;
use std::time::Duration;
use tokio::time::sleep;
use twatch_core::App;

#[tokio::main]
async fn main() -> Result<(), VarError> {
    env_logger::init();
    dotenv::dotenv().expect("to load .env");

    let url = env::var("T_URL")?;
    let user = env::var("T_USER")?;
    let password = env::var("T_PASSWORD")?;
    let cycle_seconds = env::var("T_CYCLE")
        .unwrap_or("30".to_string())
        .parse::<u64>()
        .unwrap_or(30);

    loop {
        info!("running clean up cycle");
        let _ = App::new(&url, &user, &password).run().await;
        sleep(Duration::from_secs(cycle_seconds)).await
    }
}
